# 2022-08-23 - Optimism Root Gauge Factory V2

Deployment of the `OptimismRootGaugeFactory`, for stakeless gauges that bridge funds to their Optimism counterparts. This updated version includes caps on the relative weight (allocated emissions) for each gauge.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [`OptimismRootGauge` artifact](./artifact/OptimismRootGauge.json)
- [`OptimismRootGaugeFactory` artifact](./artifact/OptimismRootGaugeFactory.json)
